/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__1I3cxybVrOXM64KW2dfERQ tySequence__1I3cxybVrOXM64KW2dfERQ;
typedef struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* resultSym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* selfSym;
NI nestedLoopCounter;
NI nestedBlockCounter;
NI inTryStmt;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* next;
NIM_BOOL mappingExists;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q mapping;
tySequence__1I3cxybVrOXM64KW2dfERQ* caseContext;
};
struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NI Field1;
};
struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* candidateType;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* prev;
NI depth;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w {
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA defaultCC;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* dynlib;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* otherPragmas;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ;
struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA {
tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tyArray__o8KQyTFgNQGvsJZYtdEsgA[8192];
struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw {
tyArray__o8KQyTFgNQGvsJZYtdEsgA buckets;
NI wordCounter;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idAnon;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idDelegator;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* emptyIdent;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* concreteTypes;
NI compilesId;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__1I3cxybVrOXM64KW2dfERQ {
  TGenericSeq Sup;
  tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__1I3cxybVrOXM64KW2dfERQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__GJ8qR6LTU9bYLzfOArsHTSg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__xjKwyxq7VMjsm1PB23RsoA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__oYkV9aFZe0MXcEAprJaOUsA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__arD7Tw6eD6lvOczWZl9buNg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__jWKvSdankQPoT5bw9cBU9aiw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__YceFcaugL2PWNtVbyffD9bQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__d4l6E4jBnTQ3BEfsLOpmEQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__EjEifkTC8tg9afiUW4StSSA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, newOptionEntry__7Bbu0XAvxF5NmG8U4F9bYrw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeS__xb5E2cGIynZweqWlCP8Tig)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**, X5BX5D___suEfaH5zF55unuYWXgUxlAsystem)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getGenSym__pT6glwCH57hiSrY6Jp4rug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, get__Bl9b9aH6mI589bl7Fqs39aKQww)(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* key);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__K5M5T7J9c0H7M5ahfeRl8xw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elem, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, errorType__9aXTnVBVS5pbBC3zrwMhttg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**, X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem)(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__LQi5FutNJyNzFfiR3Rb1Sw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeI__L1Xluv2iZ8cHbWec9bBiiaw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, nMinusOne__g3ODV709caO5lfQfPGeUxSQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, linkTo__Lxy1G9c1I40y65cWkoPnssA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(void, pop__MdRQWdS39bVEVox7mFZHqKwsystem)(tySequence__1I3cxybVrOXM64KW2dfERQ** s, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result);
static N_INLINE(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*, X5BX5D___Zk4Bc9cehxnhgKrzsAUQzmAsystem)(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, inclSym__D67OBJjdOqqA9chsEv8PV3g)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** sq, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);

/* section: NIM_merge_DATA */
extern TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
N_LIB_PRIVATE TNimType NTI__C9bB2okDBl3OKGUBiY5k5Ug_;
extern TNimType NTI__AgIT5feFR9a9aoVjv9cx2rOtg_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
extern TNimType NTI__N89ckikRqMir57209a3tEeqw_;
N_LIB_PRIVATE TNimType NTI__s5jyYR8yL1QmFqiHICzU9aQ_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__9aiv9bp2t5icFNINcg9c4xi1Q_;
N_LIB_PRIVATE TNimType NTI__FyNGItFCBJSXLJ9aJSzlX9aw_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
N_LIB_PRIVATE TNimType NTI__1I3cxybVrOXM64KW2dfERQ_;
N_LIB_PRIVATE TNimType NTI__GJ8qR6LTU9bYLzfOArsHTSg_;
N_LIB_PRIVATE TNimType NTI__9blNHn9cqK8EfxnwsfjDnKvg_;
N_LIB_PRIVATE TNimType NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__9ai78kkwqt3gikTN9cpHKUVg_;
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
N_LIB_PRIVATE TNimType NTI__H9ac5KbrDJVwT1zH5O83r7w_;
extern TNimType NTI__7MnKRybmCNh5j9bDRLMkxLw_;
extern TNimType NTI__yjAJ8w0h1PBaSwSGJ3P7IA_;
extern TNimType NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_;
extern TNimType NTI__aW7oi9a49ccVPeB9ca8RVoz8g_;
extern TNimType NTI__EzHX7W9bI4X0gV7sP2f0N9cQ_;
N_LIB_PRIVATE TNimType NTI__xjKwyxq7VMjsm1PB23RsoA_;
N_LIB_PRIVATE TNimType NTI__oYkV9aFZe0MXcEAprJaOUsA_;
N_LIB_PRIVATE TNimType NTI__arD7Tw6eD6lvOczWZl9buNg_;
N_LIB_PRIVATE TNimType NTI__RcJNn9bSvWdJgUmA1O6sbHA_;
N_LIB_PRIVATE TNimType NTI__39auogS0nN05zO6JrT7za9cQ_;
N_LIB_PRIVATE TNimType NTI__msQKNa7Ucgnt49aAZ3YRJww_;
N_LIB_PRIVATE TNimType NTI__7JwrY3AhkVNlleAJXClX9cw_;
extern TNimType NTI__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTI__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTI__qlV9aWvA5wrWVg9bI5PqwJyA_;
N_LIB_PRIVATE TNimType NTI__PiEiMdzXg9bcm3lEo4Q6iNw_;
N_LIB_PRIVATE TNimType NTI__3cacbJ4la9bDJNibHybQSnA_;
N_LIB_PRIVATE TNimType NTI__L4XfH7VEp8aJssG3EbEBaQ_;
extern TNimType NTI__f07aOS3dr28kGa5wcE29aFA_;
extern TNimType NTI__FD9cVFUpCDGxUmwW7TEZIFQ_;
N_LIB_PRIVATE TNimType NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_;
extern TNimType NTI__Y32tFilzS9adEEksgrCsOzQ_;
N_LIB_PRIVATE TNimType NTI__jWKvSdankQPoT5bw9cBU9aiw_;
N_LIB_PRIVATE TNimType NTI__9amcenQyXzP9cCQNnXZVgnYQ_;
extern TNimType NTI__B0xRsLi0eK4raPu9bd2tkcA_;
extern TNimType NTI__lnkYNZP9asc88UfiEGjLrbA_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__KlSLWBROOViO04uLQHu7ig_;
N_LIB_PRIVATE TNimType NTI__YceFcaugL2PWNtVbyffD9bQ_;
N_LIB_PRIVATE TNimType NTI__DJxbl4DYEJfb29cy1MYaUPQ_;
extern TNimType NTI__WGx4rAexNXnczy1Avn646Q_;
N_LIB_PRIVATE TNimType NTI__d4l6E4jBnTQ3BEfsLOpmEQ_;
N_LIB_PRIVATE TNimType NTI__1v9bKyksXWMsm0vNwmZ4EuQ_;
extern TNimType NTI__Gy4haGrophX9bC5RxnPAc6w_;
N_LIB_PRIVATE TNimType NTI__EjEifkTC8tg9afiUW4StSSA_;
extern TNimType NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_;
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_15, "/home/runner/work/nightlies/nightlies/nim/compiler/semdata.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_14 = {((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_15),
((NI) 429),
((NI) 13)}
;
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_16 = {((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_15),
((NI) 432),
((NI) 12)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_17, "popOwner", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_18 = {((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_15),
((NI) 174),
((NI) 21)}
;
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_19, "pred", 4);
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_20, "(", 1);
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_21, ", ", 2);
STRING_LITERAL(TM__oylmf9cXfpJWZ2cwj9b09bJaw_22, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_23 = {((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_15),
((NI) 325),
((NI) 16)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__1I3cxybVrOXM64KW2dfERQ)(void* p, NI op) {
	tySequence__1I3cxybVrOXM64KW2dfERQ* a;
	NI T1_;
	a = (tySequence__1I3cxybVrOXM64KW2dfERQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__GJ8qR6LTU9bYLzfOArsHTSg)(void* p, NI op) {
	tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* a;
	a = (tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*)p;
	nimGCvisit((void*)(*a).owner, op);
	nimGCvisit((void*)(*a).resultSym, op);
	nimGCvisit((void*)(*a).selfSym, op);
	nimGCvisit((void*)(*a).next, op);
	nimGCvisit((void*)(*a).mapping.data, op);
	nimGCvisit((void*)(*a).caseContext, op);
}
static N_NIMCALL(void, Marker_tyRef__xjKwyxq7VMjsm1PB23RsoA)(void* p, NI op) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* a;
	a = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)p;
	nimGCvisit((void*)(*a).dynlib, op);
	nimGCvisit((void*)(*a).otherPragmas, op);
}
static N_NIMCALL(void, Marker_tySequence__oYkV9aFZe0MXcEAprJaOUsA)(void* p, NI op) {
	tySequence__oYkV9aFZe0MXcEAprJaOUsA* a;
	NI T1_;
	a = (tySequence__oYkV9aFZe0MXcEAprJaOUsA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__arD7Tw6eD6lvOczWZl9buNg)(void* p, NI op) {
	tySequence__arD7Tw6eD6lvOczWZl9buNg* a;
	NI T1_;
	a = (tySequence__arD7Tw6eD6lvOczWZl9buNg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__jWKvSdankQPoT5bw9cBU9aiw)(void* p, NI op) {
	tySequence__jWKvSdankQPoT5bw9cBU9aiw* a;
	NI T1_;
	a = (tySequence__jWKvSdankQPoT5bw9cBU9aiw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].genericSym, op);
	nimGCvisit((void*)a->data[T1_].inst, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__YceFcaugL2PWNtVbyffD9bQ)(void* p, NI op) {
	tySequence__YceFcaugL2PWNtVbyffD9bQ* a;
	NI T1_;
	a = (tySequence__YceFcaugL2PWNtVbyffD9bQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__d4l6E4jBnTQ3BEfsLOpmEQ)(void* p, NI op) {
	tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* a;
	NI T1_;
	a = (tySequence__d4l6E4jBnTQ3BEfsLOpmEQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__EjEifkTC8tg9afiUW4StSSA)(void* p, NI op) {
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*)p;
	nimGCvisit((void*)(*a).enforceVoidContext, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).currentScope, op);
	nimGCvisit((void*)(*a).importTable, op);
	nimGCvisit((void*)(*a).topLevelScope, op);
	nimGCvisit((void*)(*a).p, op);
	nimGCvisit((void*)(*a).friendModules, op);
	nimGCvisit((void*)(*a).templInstCounter, op);
	nimGCvisit((void*)(*a).ambiguousSymbols.head, op);
	nimGCvisit((void*)(*a).ambiguousSymbols.data, op);
	T1_ = (NI)0;
	nimGCvisit((void*)(*a).converters, op);
	nimGCvisit((void*)(*a).patterns, op);
	nimGCvisit((void*)(*a).optionStack, op);
	nimGCvisit((void*)(*a).symMapping.data, op);
	nimGCvisit((void*)(*a).libs, op);
	nimGCvisit((void*)(*a).hasUnresolvedArgs.ClE_0, op);
	nimGCvisit((void*)(*a).semInferredLambda.ClE_0, op);
	nimGCvisit((void*)(*a).semGenerateInstance.ClE_0, op);
	nimGCvisit((void*)(*a).includedFiles.head, op);
	nimGCvisit((void*)(*a).includedFiles.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)(*a).pureEnumFields.data, op);
	nimGCvisit((void*)(*a).userPragmas.data, op);
	nimGCvisit((void*)(*a).evalContext, op);
	nimGCvisit((void*)(*a).unknownIdents.head, op);
	nimGCvisit((void*)(*a).unknownIdents.data, op);
	T3_ = (NI)0;
	nimGCvisit((void*)(*a).generics, op);
	nimGCvisit((void*)(*a).selfName, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).signatures.data, op);
	nimGCvisit((void*)(*a).recursiveDep, op);
	nimGCvisit((void*)(*a).typesWithOps, op);
	nimGCvisit((void*)(*a).unusedImports, op);
	nimGCvisit((void*)(*a).exportIndirections.data, op);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, newOptionEntry__7Bbu0XAvxF5NmG8U4F9bYrw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* result;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)0;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*) newObj((&NTI__xjKwyxq7VMjsm1PB23RsoA_), sizeof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w));
	(*result).options = (*conf).options;
	(*result).defaultCC = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0);
	asgnRef((void**) (&(*result).dynlib), ((tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*) NIM_NIL));
	nimCopyMem((void*)(*result).notes, (NIM_CONST void*)(*conf).notes, 9);
	nimCopyMem((void*)(*result).warningAsErrors, (NIM_CONST void*)(*conf).warningAsErrors, 9);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*, newContext__dfWKKRV6rIabJ2ctPOd59aA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*)0;
	result = (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) newObj((&NTI__EjEifkTC8tg9afiUW4StSSA_), sizeof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug));
	(*result).Sup.Sup.m_type = (&NTI__C9bB2okDBl3OKGUBiY5k5Ug_);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T1_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T1_).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7);
	asgnRef((void**) (&(*result).enforceVoidContext), T1_);
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).ambiguousSymbols));
	if ((*result).optionStack) { nimGCunrefNoCycle((*result).optionStack); (*result).optionStack = NIM_NIL; }
	(*result).optionStack = (tySequence__oYkV9aFZe0MXcEAprJaOUsA*) newSeqRC1((&NTI__oYkV9aFZe0MXcEAprJaOUsA_), 1);
	asgnRef((void**) (&(*result).optionStack->data[0]), newOptionEntry__7Bbu0XAvxF5NmG8U4F9bYrw((*graph).config));
	if ((*result).libs) { nimGCunrefNoCycle((*result).libs); (*result).libs = NIM_NIL; }
	asgnRef((void**) (&(*result).module), module);
	if ((*result).friendModules) { nimGCunrefNoCycle((*result).friendModules); (*result).friendModules = NIM_NIL; }
	(*result).friendModules = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) newSeqRC1((&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), 1);
	asgnRef((void**) (&(*result).friendModules->data[0]), module);
	if ((*result).converters) { nimGCunrefNoCycle((*result).converters); (*result).converters = NIM_NIL; }
	if ((*result).patterns) { nimGCunrefNoCycle((*result).patterns); (*result).patterns = NIM_NIL; }
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).includedFiles));
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).pureEnumFields));
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).userPragmas));
	if ((*result).generics) { nimGCunrefNoCycle((*result).generics); (*result).generics = NIM_NIL; }
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).unknownIdents));
	asgnRef((void**) (&(*result).cache), (*graph).cache);
	asgnRef((void**) (&(*result).graph), graph);
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).signatures));
	if ((*result).typesWithOps) { nimGCunrefNoCycle((*result).typesWithOps); (*result).typesWithOps = NIM_NIL; }
	(*result).features = (*(*graph).config).features;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 2), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__oylmf9cXfpJWZ2cwj9b09bJaw_14, NIM_FALSE);
}
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**, X5BX5D___suEfaH5zF55unuYWXgUxlAsystem)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** s, NI sLen_0, NI i) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
	T1_ = X5BX5D___suEfaH5zF55unuYWXgUxlAsystem((*(*c).graph).owners->data, ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeS__xb5E2cGIynZweqWlCP8Tig)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = newType__SNqpa06pdVCLFFBR28119aQ(kind, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61), c);
	asgnRef((void**) (&(*result).n), n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, errorType__9aXTnVBVS5pbBC3zrwMhttg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), c);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeDesc__BhLel1oiCddEysrc3uc6iQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA3_;
		result = typ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), c);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, typ);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__EezdXeDvu4rB7fR84AJZgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI length, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == length))) goto LA4_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, conf);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = newType__SNqpa06pdVCLFFBR28119aQ(kind, T1_);
	genericSeqAssign((&(*result).sons), sons, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 62), (*n).info);
	if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
	(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), 1);
	asgnRef((void**) (&(*result)._kind_6.sons->data[0]), n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
		LA4_: ;
		if (!T3_) goto LA5_;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	goto LA1_;
	LA5_: ;
	{
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T8_;
		T8_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T8_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
		asgnRef((void**) (&T8_->data[0]), (*n).typ);
		asgnRef((void**) (&(*result).typ), newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T8_));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NI64 first, NI64 last, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType_2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!!((intType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		intType_2 = intType;
	}
	goto LA1_;
	LA3_: ;
	{
		intType_2 = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	}
	LA1_: ;
	n = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), info);
	T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T6_ = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(first, intType_2);
	add__P8dDSotTW25BkfbyspojGg(n, T6_);
	T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T7_ = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(last, intType_2);
	add__P8dDSotTW25BkfbyspojGg(n, T7_);
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), c);
	asgnRef((void**) (&(*result).n), n);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, intType_2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, get__Bl9b9aH6mI589bl7Fqs39aKQww)(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* key) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T5_;
	RootObj* T6_;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!!((*p).mappingExists)) goto LA3_;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
	T5_ = &key->Sup;
	T6_ = (RootObj*)0;
	T6_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*p).mapping, T5_);
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) (T6_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getGenSym__pT6glwCH57hiSrY6Jp4rug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* it;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA3_;
		result = s;
		goto BeforeRet_;
	}
	LA3_: ;
	it = (*c).p;
	{
		while (1) {
			if (!!((it == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)))) goto LA6;
			result = get__Bl9b9aH6mI589bl7Fqs39aKQww(it, s);
			{
				if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9_;
				goto BeforeRet_;
			}
			LA9_: ;
			it = (*it).next;
		} LA6: ;
	}
	result = s;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		s = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, (*n)._kind_4.sym);
		{
			if (!!(((*n)._kind_4.sym == s))) goto LA7_;
			asgnRef((void**) (&(*n)._kind_4.sym), s);
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeVarType__45x39aIZGLTdqqo59b4NHvLw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*baseType).kind == kind)) goto LA3_;
		result = baseType;
	}
	goto LA1_;
	LA3_: ;
	{
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(kind, c);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, baseType);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeVarType__1XhuXEO6E22P9aDkvWkNrHQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*baseType).kind == kind)) goto LA3_;
		result = baseType;
	}
	goto LA1_;
	LA3_: ;
	{
		result = newType__SNqpa06pdVCLFFBR28119aQ(kind, owner);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, baseType);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__aOnJJ9cXkOooTyUuLmnc09bw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 2), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__oylmf9cXfpJWZ2cwj9b09bJaw_16, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeAndType__9b4dTSY3d7uIjSch9cj9cGP1w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 2);
	asgnRef((void**) (&(*result).sons->data[0]), t1);
	asgnRef((void**) (&(*result).sons->data[1]), t2);
	propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, t1, NIM_TRUE);
	propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, t2, NIM_TRUE);
	(*result).flags = ((*result).flags | (((*t1).flags | (*t2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeOrType__9b4dTSY3d7uIjSch9cj9cGP1w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57), c);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t1).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57)));
		LA4_: ;
		if (!T3_) goto LA5_;
		if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
		(*result).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 2);
		asgnRef((void**) (&(*result).sons->data[0]), t1);
		asgnRef((void**) (&(*result).sons->data[1]), t2);
	}
	goto LA1_;
	LA5_: ;
	{
		{
			if (!((*t1).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57))) goto LA10_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** xX60gensym41_;
				NI i;
				NI L;
				NI T13_;
				xX60gensym41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i = ((NI) 0);
				T13_ = ((*t1).sons ? (*t1).sons->Sup.len : 0);
				L = T13_;
				{
					while (1) {
						if (!(i < L)) goto LA15;
						xX60gensym41_ = &(*t1).sons->data[i];
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, (*xX60gensym41_), NIM_TRUE);
						i += ((NI) 1);
					} LA15: ;
				}
			}
		}
		goto LA8_;
		LA10_: ;
		{
			rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, t1, NIM_TRUE);
		}
		LA8_: ;
		{
			if (!((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57))) goto LA19_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** xX60gensym42_;
				NI i_2;
				NI L_2;
				NI T22_;
				xX60gensym42_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i_2 = ((NI) 0);
				T22_ = ((*t2).sons ? (*t2).sons->Sup.len : 0);
				L_2 = T22_;
				{
					while (1) {
						if (!(i_2 < L_2)) goto LA24;
						xX60gensym42_ = &(*t2).sons->data[i_2];
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, (*xX60gensym42_), NIM_TRUE);
						i_2 += ((NI) 1);
					} LA24: ;
				}
			}
		}
		goto LA17_;
		LA19_: ;
		{
			rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, t2, NIM_TRUE);
		}
		LA17_: ;
	}
	LA1_: ;
	propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, t1, NIM_TRUE);
	propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, t2, NIM_TRUE);
	(*result).flags = ((*result).flags | (((*t1).flags | (*t2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeNotType__UPDD9aO4WRk8hLMnfpJZudg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
	asgnRef((void**) (&(*result).sons->data[0]), t1);
	propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, t1, NIM_TRUE);
	(*result).flags = ((*result).flags | ((*t1).flags & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI length, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ < length)) goto LA4_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, conf);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	NI T1_;
	asgnRef((void**) (&(*(*c).graph).owners), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*(*c).graph).owners), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T1_ = (*(*c).graph).owners->Sup.len++;
	asgnRef((void**) (&(*(*c).graph).owners->data[T1_]), owner);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, errorNode__g3ODV709caO5lfQfPGeUxSQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
	asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, makeInstPair__OBM04JqIpDFmR9bhgy9ckD3w)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst, tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ* Result) {
	unsureAsgnRef((void**)&(*Result).genericSym, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).inst, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).genericSym), s);
	unsureAsgnRef((void**) (&(*Result).inst), inst);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*, newLib__rs8ukRH9beqw1tk0hnXjBtg)(tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind) {
	tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* result;
	result = (tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*)0;
	result = (tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*) newObj((&NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_), sizeof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA));
	(*result).kind = kind;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToLib__xoFj1Tk9cDOsrW8yALZcxCA)(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	asgnRef((void**) (&(*sym).annex), lib);
}
static N_INLINE(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**, X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem)(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** s, NI sLen_0, NI i) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** result;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, pushOptionEntry__SQasfuhUR9aUpH0EyW9aFezg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* result;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* prev;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T1_;
	NI T2_;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)0;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*) newObj((&NTI__xjKwyxq7VMjsm1PB23RsoA_), sizeof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w));
	T1_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T1_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	prev = (*T1_);
	(*result).options = (*(*(*c).graph).config).options;
	(*result).defaultCC = (*prev).defaultCC;
	asgnRef((void**) (&(*result).dynlib), (*prev).dynlib);
	nimCopyMem((void*)(*result).notes, (NIM_CONST void*)(*(*(*c).graph).config).notes, 9);
	nimCopyMem((void*)(*result).warningAsErrors, (NIM_CONST void*)(*(*(*c).graph).config).warningAsErrors, 9);
	(*result).features = (*c).features;
	asgnRef((void**) (&(*c).optionStack), (tySequence__oYkV9aFZe0MXcEAprJaOUsA*) incrSeqV3((TGenericSeq*)((*c).optionStack), (&NTI__oYkV9aFZe0MXcEAprJaOUsA_)));
	T2_ = (*c).optionStack->Sup.len++;
	asgnRef((void**) (&(*c).optionStack->data[T2_]), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__9aY89b9aR25iMJ8fPdM84CvQg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T1_;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T2_;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T3_;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T4_;
	NI T5_;
	T1_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T1_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	(*(*(*c).graph).config).options = (*(*T1_)).options;
	T2_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T2_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	nimCopyMem((void*)(*(*(*c).graph).config).notes, (NIM_CONST void*)(*(*T2_)).notes, 9);
	T3_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T3_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	nimCopyMem((void*)(*(*(*c).graph).config).warningAsErrors, (NIM_CONST void*)(*(*T3_)).warningAsErrors, 9);
	T4_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T4_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	(*c).features = (*(*T4_)).features;
	T5_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
	asgnRef((void**) (&(*c).optionStack), (tySequence__oYkV9aFZe0MXcEAprJaOUsA*) setLengthSeqV2(&((*c).optionStack)->Sup, (&NTI__oYkV9aFZe0MXcEAprJaOUsA_), ((NI) ((NI)(T5_ - ((NI) 1))))));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, lastOptionEntry__SQasfuhUR9aUpH0EyW9aFezg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* result;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T1_;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)0;
	T1_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	T1_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	{
		NI T3_;
		NI T6_;
		T3_ = ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0);
		if (!(((NI) 0) < T3_)) goto LA4_;
		T6_ = ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0);
		asgnRef((void**) (&(*(*c).graph).owners), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*(*c).graph).owners)->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) ((NI)(T6_ - ((NI) 1))))));
	}
	goto LA1_;
	LA4_: ;
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_17), TM__oylmf9cXfpJWZ2cwj9b09bJaw_18);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__LQi5FutNJyNzFfiR3Rb1Sw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), owner);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, baseType);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__PDWeh9cjpi22xXdNggYvsWA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = makePtrType__LQi5FutNJyNzFfiR3Rb1Sw(T1_, baseType);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__aSykZlHQuGR9almJ1ehcUew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(kind, owner);
	genericSeqAssign((&(*result).sons), sons, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_));
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, nMinusOne__g3ODV709caO5lfQfPGeUxSQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*c).graph, (*n).info, ((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_19), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52));
	T1_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T2_);
	T1_[1] = n;
	result = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T1_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeRangeWithStaticExpr__D2YW7F23KYvdV39aTScM3IQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T7_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	intType = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
	asgnRef((void**) (&(*result).sons->data[0]), intType);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
	}
	LA5_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T7_[0] = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(0), intType);
	T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T8_ = nMinusOne__g3ODV709caO5lfQfPGeUxSQ_3(c, n);
	T7_[1] = makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ(c, T8_);
	asgnRef((void**) (&(*result).n), newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), (*n).info, T7_, 2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeWithModifier__YyNjY7O2UpEApULCS9ctQYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag modifier, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((IL64(140737496744192) &((NU64)1<<((NU)(modifier)&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = ((*baseType).kind == modifier);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = baseType;
	}
	goto LA1_;
	LA5_: ;
	{
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(modifier, c);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, baseType);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_20));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_21));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__oylmf9cXfpJWZ2cwj9b09bJaw_22));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeTypeSymNode__L4oMECPyC3ttpx9cr0kf9a9bw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typedesc;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T6_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	typedesc = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), c);
	(*typedesc).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
	{
		NimStringDesc* argX60gensym31_;
		if (!!(!((typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))))) goto LA3_;
		argX60gensym31_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__oylmf9cXfpJWZ2cwj9b09bJaw_23);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym31_, TM__oylmf9cXfpJWZ2cwj9b09bJaw_23);
	}
	LA3_: ;
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(typedesc, typ);
	T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T5_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	T6_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T6_ = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), (*(*c).cache).idAnon, T5_, info, (*(*(*c).graph).config).options);
	sym = linkTo__Lxy1G9c1I40y65cWkoPnssA(T6_, typedesc);
	result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(sym, info);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushCaseContext__Hz1YayV9c9aSkUcvf7h2lHXQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseNode) {
	tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw T1_;
	NI T2_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw));
	T1_.Field0 = caseNode;
	T1_.Field1 = ((NI) 0);
	asgnRef((void**) (&(*(*c).p).caseContext), (tySequence__1I3cxybVrOXM64KW2dfERQ*) incrSeqV3((TGenericSeq*)((*(*c).p).caseContext), (&NTI__1I3cxybVrOXM64KW2dfERQ_)));
	T2_ = (*(*c).p).caseContext->Sup.len++;
	asgnRef((void**) (&(*(*c).p).caseContext->data[T2_].Field0), T1_.Field0);
	(*(*c).p).caseContext->data[T2_].Field1 = T1_.Field1;
}
static N_INLINE(void, pop__MdRQWdS39bVEVox7mFZHqKwsystem)(tySequence__1I3cxybVrOXM64KW2dfERQ** s, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result) {
	NI L;
	NI T1_;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), (*s)->data[L].Field0);
	(*Result).Field1 = (*s)->data[L].Field1;
	unsureAsgnRef((void**) (&(*s)), (tySequence__1I3cxybVrOXM64KW2dfERQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__1I3cxybVrOXM64KW2dfERQ_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(void, popCaseContext__9aY89b9aR25iMJ8fPdM84CvQg_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw));
	pop__MdRQWdS39bVEVox7mFZHqKwsystem((&(*(*c).p).caseContext), (&T1_));
	(void)(T1_);
}
static N_INLINE(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*, X5BX5D___Zk4Bc9cehxnhgKrzsAUQzmAsystem)(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* s, NI sLen_0, NI i) {
	tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* result;
	result = (tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setCaseContextIdx__jiOUhpYURJJFfrdMgAQxPQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NI idx) {
	tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* T1_;
	T1_ = (tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*)0;
	T1_ = X5BX5D___Zk4Bc9cehxnhgKrzsAUQzmAsystem((*(*c).p).caseContext->data, ((*(*c).p).caseContext ? (*(*c).p).caseContext->Sup.len : 0), ((NI) 1));
	(*T1_).Field1 = idx;
}
N_LIB_PRIVATE N_NIMCALL(void, inclSym__D67OBJjdOqqA9chsEv8PV3g)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** sq, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NI T9_;
{	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*sq) ? (*sq)->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!((*(*sq)->data[i]).Sup.id == (*s).Sup.id)) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*sq)), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*sq)), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T9_ = (*sq)->Sup.len++;
	asgnRef((void**) (&(*sq)->data[T9_]), s);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverter__ymX9afTGg7YU9b9aXV3gliVtA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conv) {
	inclSym__D67OBJjdOqqA9chsEv8PV3g((&(*c).converters), conv);
}
N_LIB_PRIVATE N_NIMCALL(void, addPattern__i62yfG9bHBj1PZBSZ7lMCCA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p) {
	inclSym__D67OBJjdOqqA9chsEv8PV3g((&(*c).patterns), p);
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_semdataDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[57];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[10];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_4_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_5_3[3];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[7];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_7_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_8_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_9_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_10_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_11_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_12_2[2];
static TNimNode* TM__oylmf9cXfpJWZ2cwj9b09bJaw_13_2[2];
static TNimNode TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[105];

/* section: NIM_merge_TYPE_INIT3 */
NTI__C9bB2okDBl3OKGUBiY5k5Ug_.size = sizeof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug);
NTI__C9bB2okDBl3OKGUBiY5k5Ug_.align = NIM_ALIGNOF(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug);
NTI__C9bB2okDBl3OKGUBiY5k5Ug_.kind = 17;
NTI__C9bB2okDBl3OKGUBiY5k5Ug_.base = (&NTI__Hb6rFM0ecvtlLf2kv9aU75w_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[1];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[1].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[1].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, enforceVoidContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[1].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[1].name = "enforceVoidContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[2];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[2].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[2].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, module);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[2].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[2].name = "module";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[2] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[3];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[3].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[3].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, currentScope);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[3].typ = (&NTI__N89ckikRqMir57209a3tEeqw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[3].name = "currentScope";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[3] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[4];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[4].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[4].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, importTable);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[4].typ = (&NTI__N89ckikRqMir57209a3tEeqw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[4].name = "importTable";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[4] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[5];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[5].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[5].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, topLevelScope);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[5].typ = (&NTI__N89ckikRqMir57209a3tEeqw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[5].name = "topLevelScope";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[5] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[6];
NTI__s5jyYR8yL1QmFqiHICzU9aQ_.size = sizeof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ);
NTI__s5jyYR8yL1QmFqiHICzU9aQ_.align = NIM_ALIGNOF(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ);
NTI__s5jyYR8yL1QmFqiHICzU9aQ_.kind = 18;
NTI__s5jyYR8yL1QmFqiHICzU9aQ_.base = 0;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[8];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[8].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[8].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, owner);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[8].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[8].name = "owner";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[9];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[9].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[9].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, resultSym);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[9].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[9].name = "resultSym";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[2] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[10];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[10].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[10].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, selfSym);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[10].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[10].name = "selfSym";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[3] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[11];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[11].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[11].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, nestedLoopCounter);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[11].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[11].name = "nestedLoopCounter";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[4] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[12];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[12].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[12].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, nestedBlockCounter);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[12].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[12].name = "nestedBlockCounter";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[5] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[13];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[13].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[13].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, inTryStmt);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[13].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[13].name = "inTryStmt";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[6] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[14];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[14].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[14].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, next);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[14].typ = (&NTI__GJ8qR6LTU9bYLzfOArsHTSg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[14].name = "next";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[7] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[15];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[15].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[15].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, mappingExists);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[15].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[15].name = "mappingExists";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[8] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[16];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[16].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[16].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, mapping);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[16].typ = (&NTI__9aiv9bp2t5icFNINcg9c4xi1Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[16].name = "mapping";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[9] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[17];
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.size = sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw);
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.align = NIM_ALIGNOF(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw);
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.kind = 18;
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.base = 0;
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_4_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[19];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[19].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[19].offset = offsetof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[19].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[19].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_4_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[20];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[20].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[20].offset = offsetof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[20].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[20].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[18].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[18].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[18].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_4_2[0];
NTI__FyNGItFCBJSXLJ9aJSzlX9aw_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[18];
NTI__1I3cxybVrOXM64KW2dfERQ_.size = sizeof(tySequence__1I3cxybVrOXM64KW2dfERQ*);
NTI__1I3cxybVrOXM64KW2dfERQ_.align = NIM_ALIGNOF(tySequence__1I3cxybVrOXM64KW2dfERQ*);
NTI__1I3cxybVrOXM64KW2dfERQ_.kind = 24;
NTI__1I3cxybVrOXM64KW2dfERQ_.base = (&NTI__FyNGItFCBJSXLJ9aJSzlX9aw_);
NTI__1I3cxybVrOXM64KW2dfERQ_.flags = 2;
NTI__1I3cxybVrOXM64KW2dfERQ_.marker = Marker_tySequence__1I3cxybVrOXM64KW2dfERQ;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[17].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[17].offset = offsetof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ, caseContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[17].typ = (&NTI__1I3cxybVrOXM64KW2dfERQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[17].name = "caseContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[7].len = 10; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[7].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[7].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_3_10[0];
NTI__s5jyYR8yL1QmFqiHICzU9aQ_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[7];
NTI__GJ8qR6LTU9bYLzfOArsHTSg_.size = sizeof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*);
NTI__GJ8qR6LTU9bYLzfOArsHTSg_.align = NIM_ALIGNOF(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*);
NTI__GJ8qR6LTU9bYLzfOArsHTSg_.kind = 22;
NTI__GJ8qR6LTU9bYLzfOArsHTSg_.base = (&NTI__s5jyYR8yL1QmFqiHICzU9aQ_);
NTI__GJ8qR6LTU9bYLzfOArsHTSg_.marker = Marker_tyRef__GJ8qR6LTU9bYLzfOArsHTSg;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[6].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[6].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, p);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[6].typ = (&NTI__GJ8qR6LTU9bYLzfOArsHTSg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[6].name = "p";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[6] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[21];
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.size = sizeof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg);
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.align = NIM_ALIGNOF(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg);
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.kind = 18;
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.base = 0;
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_5_3[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[23];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[23].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[23].offset = offsetof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg, candidateType);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[23].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[23].name = "candidateType";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_5_3[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[24];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[24].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[24].offset = offsetof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg, prev);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[24].typ = (&NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[24].name = "prev";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_5_3[2] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[25];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[25].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[25].offset = offsetof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg, depth);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[25].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[25].name = "depth";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[22].len = 3; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[22].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[22].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_5_3[0];
NTI__9blNHn9cqK8EfxnwsfjDnKvg_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[22];
NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_.size = sizeof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*);
NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_.align = NIM_ALIGNOF(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*);
NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_.kind = 21;
NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_.base = (&NTI__9blNHn9cqK8EfxnwsfjDnKvg_);
NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[21].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[21].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, matchedConcept);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[21].typ = (&NTI__9bxt5LVCQF9cIw2NKtMTCXzQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[21].name = "matchedConcept";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[7] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[26];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[26].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[26].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, friendModules);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[26].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[26].name = "friendModules";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[8] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[27];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[27].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[27].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, instCounter);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[27].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[27].name = "instCounter";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[9] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[28];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[28].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[28].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, templInstCounter);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[28].typ = (&NTI__9ai78kkwqt3gikTN9cpHKUVg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[28].name = "templInstCounter";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[10] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[29];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[29].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[29].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, ambiguousSymbols);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[29].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[29].name = "ambiguousSymbols";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[11] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[30];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[30].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[30].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inGenericContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[30].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[30].name = "inGenericContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[12] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[31];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[31].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[31].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inStaticContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[31].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[31].name = "inStaticContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[13] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[32];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[32].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[32].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inUnrolledContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[32].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[32].name = "inUnrolledContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[14] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[33];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[33].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[33].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, compilesContextId);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[33].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[33].name = "compilesContextId";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[15] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[34];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[34].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[34].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, compilesContextIdGenerator);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[34].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[34].name = "compilesContextIdGenerator";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[16] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[35];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[35].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[35].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inGenericInst);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[35].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[35].name = "inGenericInst";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[17] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[36];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[36].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[36].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, converters);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[36].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[36].name = "converters";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[18] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[37];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[37].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[37].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, patterns);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[37].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[37].name = "patterns";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[19] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[38];
NTI__H9ac5KbrDJVwT1zH5O83r7w_.size = sizeof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w);
NTI__H9ac5KbrDJVwT1zH5O83r7w_.align = NIM_ALIGNOF(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w);
NTI__H9ac5KbrDJVwT1zH5O83r7w_.kind = 18;
NTI__H9ac5KbrDJVwT1zH5O83r7w_.base = 0;
NTI__H9ac5KbrDJVwT1zH5O83r7w_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[40];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[40].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[40].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, options);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[40].typ = (&NTI__7MnKRybmCNh5j9bDRLMkxLw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[40].name = "options";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[41];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[41].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[41].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, defaultCC);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[41].typ = (&NTI__yjAJ8w0h1PBaSwSGJ3P7IA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[41].name = "defaultCC";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[2] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[42];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[42].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[42].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, dynlib);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[42].typ = (&NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[42].name = "dynlib";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[3] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[43];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[43].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[43].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, notes);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[43].typ = (&NTI__aW7oi9a49ccVPeB9ca8RVoz8g_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[43].name = "notes";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[4] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[44];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[44].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[44].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, features);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[44].typ = (&NTI__EzHX7W9bI4X0gV7sP2f0N9cQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[44].name = "features";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[5] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[45];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[45].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[45].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, otherPragmas);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[45].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[45].name = "otherPragmas";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[6] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[46];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[46].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[46].offset = offsetof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w, warningAsErrors);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[46].typ = (&NTI__aW7oi9a49ccVPeB9ca8RVoz8g_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[46].name = "warningAsErrors";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[39].len = 7; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[39].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[39].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_6_7[0];
NTI__H9ac5KbrDJVwT1zH5O83r7w_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[39];
NTI__xjKwyxq7VMjsm1PB23RsoA_.size = sizeof(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*);
NTI__xjKwyxq7VMjsm1PB23RsoA_.align = NIM_ALIGNOF(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*);
NTI__xjKwyxq7VMjsm1PB23RsoA_.kind = 22;
NTI__xjKwyxq7VMjsm1PB23RsoA_.base = (&NTI__H9ac5KbrDJVwT1zH5O83r7w_);
NTI__xjKwyxq7VMjsm1PB23RsoA_.flags = 2;
NTI__xjKwyxq7VMjsm1PB23RsoA_.marker = Marker_tyRef__xjKwyxq7VMjsm1PB23RsoA;
NTI__oYkV9aFZe0MXcEAprJaOUsA_.size = sizeof(tySequence__oYkV9aFZe0MXcEAprJaOUsA*);
NTI__oYkV9aFZe0MXcEAprJaOUsA_.align = NIM_ALIGNOF(tySequence__oYkV9aFZe0MXcEAprJaOUsA*);
NTI__oYkV9aFZe0MXcEAprJaOUsA_.kind = 24;
NTI__oYkV9aFZe0MXcEAprJaOUsA_.base = (&NTI__xjKwyxq7VMjsm1PB23RsoA_);
NTI__oYkV9aFZe0MXcEAprJaOUsA_.flags = 2;
NTI__oYkV9aFZe0MXcEAprJaOUsA_.marker = Marker_tySequence__oYkV9aFZe0MXcEAprJaOUsA;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[38].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[38].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, optionStack);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[38].typ = (&NTI__oYkV9aFZe0MXcEAprJaOUsA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[38].name = "optionStack";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[20] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[47];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[47].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[47].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, symMapping);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[47].typ = (&NTI__9aiv9bp2t5icFNINcg9c4xi1Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[47].name = "symMapping";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[21] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[48];
NTI__arD7Tw6eD6lvOczWZl9buNg_.size = sizeof(tySequence__arD7Tw6eD6lvOczWZl9buNg*);
NTI__arD7Tw6eD6lvOczWZl9buNg_.align = NIM_ALIGNOF(tySequence__arD7Tw6eD6lvOczWZl9buNg*);
NTI__arD7Tw6eD6lvOczWZl9buNg_.kind = 24;
NTI__arD7Tw6eD6lvOczWZl9buNg_.base = (&NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_);
NTI__arD7Tw6eD6lvOczWZl9buNg_.flags = 2;
NTI__arD7Tw6eD6lvOczWZl9buNg_.marker = Marker_tySequence__arD7Tw6eD6lvOczWZl9buNg;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[48].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[48].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, libs);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[48].typ = (&NTI__arD7Tw6eD6lvOczWZl9buNg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[48].name = "libs";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[22] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[49];
NTI__RcJNn9bSvWdJgUmA1O6sbHA_.size = sizeof(tyProc__RcJNn9bSvWdJgUmA1O6sbHA);
NTI__RcJNn9bSvWdJgUmA1O6sbHA_.align = NIM_ALIGNOF(tyProc__RcJNn9bSvWdJgUmA1O6sbHA);
NTI__RcJNn9bSvWdJgUmA1O6sbHA_.kind = 25;
NTI__RcJNn9bSvWdJgUmA1O6sbHA_.base = 0;
NTI__RcJNn9bSvWdJgUmA1O6sbHA_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[49].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[49].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semConstExpr);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[49].typ = (&NTI__RcJNn9bSvWdJgUmA1O6sbHA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[49].name = "semConstExpr";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[23] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[50];
NTI__39auogS0nN05zO6JrT7za9cQ_.size = sizeof(tyProc__39auogS0nN05zO6JrT7za9cQ);
NTI__39auogS0nN05zO6JrT7za9cQ_.align = NIM_ALIGNOF(tyProc__39auogS0nN05zO6JrT7za9cQ);
NTI__39auogS0nN05zO6JrT7za9cQ_.kind = 25;
NTI__39auogS0nN05zO6JrT7za9cQ_.base = 0;
NTI__39auogS0nN05zO6JrT7za9cQ_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[50].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[50].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semExpr);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[50].typ = (&NTI__39auogS0nN05zO6JrT7za9cQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[50].name = "semExpr";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[24] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[51];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[51].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[51].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semTryExpr);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[51].typ = (&NTI__39auogS0nN05zO6JrT7za9cQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[51].name = "semTryExpr";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[25] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[52];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[52].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[52].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semTryConstExpr);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[52].typ = (&NTI__RcJNn9bSvWdJgUmA1O6sbHA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[52].name = "semTryConstExpr";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[26] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[53];
NTI__msQKNa7Ucgnt49aAZ3YRJww_.size = sizeof(tyProc__msQKNa7Ucgnt49aAZ3YRJww);
NTI__msQKNa7Ucgnt49aAZ3YRJww_.align = NIM_ALIGNOF(tyProc__msQKNa7Ucgnt49aAZ3YRJww);
NTI__msQKNa7Ucgnt49aAZ3YRJww_.kind = 25;
NTI__msQKNa7Ucgnt49aAZ3YRJww_.base = 0;
NTI__msQKNa7Ucgnt49aAZ3YRJww_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[53].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[53].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, computeRequiresInit);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[53].typ = (&NTI__msQKNa7Ucgnt49aAZ3YRJww_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[53].name = "computeRequiresInit";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[27] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[54];
NTI__7JwrY3AhkVNlleAJXClX9cw_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__7JwrY3AhkVNlleAJXClX9cw_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__7JwrY3AhkVNlleAJXClX9cw_.kind = 18;
NTI__7JwrY3AhkVNlleAJXClX9cw_.base = 0;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_7_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[56];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[56].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[56].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[56].typ = (&NTI__vr5DoT1jILTGdRlYv1OYpw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[56].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_7_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[57];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[57].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[57].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[57].typ = (&NTI__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[57].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[55].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[55].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[55].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_7_2[0];
NTI__7JwrY3AhkVNlleAJXClX9cw_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[55];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[54].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[54].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, hasUnresolvedArgs);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[54].typ = (&NTI__7JwrY3AhkVNlleAJXClX9cw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[54].name = "hasUnresolvedArgs";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[28] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[58];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[58].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[58].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semOperand);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[58].typ = (&NTI__39auogS0nN05zO6JrT7za9cQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[58].name = "semOperand";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[29] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[59];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[59].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[59].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semConstBoolExpr);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[59].typ = (&NTI__RcJNn9bSvWdJgUmA1O6sbHA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[59].name = "semConstBoolExpr";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[30] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[60];
NTI__qlV9aWvA5wrWVg9bI5PqwJyA_.size = sizeof(tyProc__qlV9aWvA5wrWVg9bI5PqwJyA);
NTI__qlV9aWvA5wrWVg9bI5PqwJyA_.align = NIM_ALIGNOF(tyProc__qlV9aWvA5wrWVg9bI5PqwJyA);
NTI__qlV9aWvA5wrWVg9bI5PqwJyA_.kind = 25;
NTI__qlV9aWvA5wrWVg9bI5PqwJyA_.base = 0;
NTI__qlV9aWvA5wrWVg9bI5PqwJyA_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[60].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[60].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semOverloadedCall);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[60].typ = (&NTI__qlV9aWvA5wrWVg9bI5PqwJyA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[60].name = "semOverloadedCall";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[31] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[61];
NTI__PiEiMdzXg9bcm3lEo4Q6iNw_.size = sizeof(tyProc__PiEiMdzXg9bcm3lEo4Q6iNw);
NTI__PiEiMdzXg9bcm3lEo4Q6iNw_.align = NIM_ALIGNOF(tyProc__PiEiMdzXg9bcm3lEo4Q6iNw);
NTI__PiEiMdzXg9bcm3lEo4Q6iNw_.kind = 25;
NTI__PiEiMdzXg9bcm3lEo4Q6iNw_.base = 0;
NTI__PiEiMdzXg9bcm3lEo4Q6iNw_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[61].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[61].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semTypeNode);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[61].typ = (&NTI__PiEiMdzXg9bcm3lEo4Q6iNw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[61].name = "semTypeNode";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[32] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[62];
NTI__3cacbJ4la9bDJNibHybQSnA_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__3cacbJ4la9bDJNibHybQSnA_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__3cacbJ4la9bDJNibHybQSnA_.kind = 18;
NTI__3cacbJ4la9bDJNibHybQSnA_.base = 0;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_8_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[64];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[64].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[64].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[64].typ = (&NTI__vr5DoT1jILTGdRlYv1OYpw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[64].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_8_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[65];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[65].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[65].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[65].typ = (&NTI__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[65].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[63].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[63].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[63].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_8_2[0];
NTI__3cacbJ4la9bDJNibHybQSnA_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[63];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[62].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[62].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semInferredLambda);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[62].typ = (&NTI__3cacbJ4la9bDJNibHybQSnA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[62].name = "semInferredLambda";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[33] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[66];
NTI__L4XfH7VEp8aJssG3EbEBaQ_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__L4XfH7VEp8aJssG3EbEBaQ_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__L4XfH7VEp8aJssG3EbEBaQ_.kind = 18;
NTI__L4XfH7VEp8aJssG3EbEBaQ_.base = 0;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_9_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[68];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[68].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[68].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[68].typ = (&NTI__vr5DoT1jILTGdRlYv1OYpw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[68].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_9_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[69];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[69].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[69].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[69].typ = (&NTI__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[69].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[67].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[67].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[67].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_9_2[0];
NTI__L4XfH7VEp8aJssG3EbEBaQ_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[67];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[66].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[66].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, semGenerateInstance);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[66].typ = (&NTI__L4XfH7VEp8aJssG3EbEBaQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[66].name = "semGenerateInstance";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[34] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[70];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[70].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[70].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, includedFiles);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[70].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[70].name = "includedFiles";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[35] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[71];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[71].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[71].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, pureEnumFields);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[71].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[71].name = "pureEnumFields";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[36] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[72];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[72].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[72].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, userPragmas);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[72].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[72].name = "userPragmas";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[37] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[73];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[73].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[73].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, evalContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[73].typ = (&NTI__FD9cVFUpCDGxUmwW7TEZIFQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[73].name = "evalContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[38] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[74];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[74].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[74].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, unknownIdents);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[74].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[74].name = "unknownIdents";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[39] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[75];
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.size = sizeof(tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ);
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.align = NIM_ALIGNOF(tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ);
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.kind = 18;
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.base = 0;
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_10_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[77];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[77].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[77].offset = offsetof(tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ, genericSym);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[77].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[77].name = "genericSym";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_10_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[78];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[78].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[78].offset = offsetof(tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ, inst);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[78].typ = (&NTI__Y32tFilzS9adEEksgrCsOzQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[78].name = "inst";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[76].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[76].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[76].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_10_2[0];
NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[76];
NTI__jWKvSdankQPoT5bw9cBU9aiw_.size = sizeof(tySequence__jWKvSdankQPoT5bw9cBU9aiw*);
NTI__jWKvSdankQPoT5bw9cBU9aiw_.align = NIM_ALIGNOF(tySequence__jWKvSdankQPoT5bw9cBU9aiw*);
NTI__jWKvSdankQPoT5bw9cBU9aiw_.kind = 24;
NTI__jWKvSdankQPoT5bw9cBU9aiw_.base = (&NTI__HkXM4cJmOpk8zFcmq9c9c3gQ_);
NTI__jWKvSdankQPoT5bw9cBU9aiw_.flags = 2;
NTI__jWKvSdankQPoT5bw9cBU9aiw_.marker = Marker_tySequence__jWKvSdankQPoT5bw9cBU9aiw;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[75].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[75].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, generics);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[75].typ = (&NTI__jWKvSdankQPoT5bw9cBU9aiw_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[75].name = "generics";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[40] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[79];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[79].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[79].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, topStmts);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[79].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[79].name = "topStmts";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[41] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[80];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[80].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[80].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, lastGenericIdx);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[80].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[80].name = "lastGenericIdx";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[42] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[81];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[81].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[81].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, hloLoopDetector);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[81].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[81].name = "hloLoopDetector";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[43] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[82];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[82].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[82].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inParallelStmt);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[82].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[82].name = "inParallelStmt";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[44] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[83];
NTI__9amcenQyXzP9cCQNnXZVgnYQ_.size = sizeof(tyProc__9amcenQyXzP9cCQNnXZVgnYQ);
NTI__9amcenQyXzP9cCQNnXZVgnYQ_.align = NIM_ALIGNOF(tyProc__9amcenQyXzP9cCQNnXZVgnYQ);
NTI__9amcenQyXzP9cCQNnXZVgnYQ_.kind = 25;
NTI__9amcenQyXzP9cCQNnXZVgnYQ_.base = 0;
NTI__9amcenQyXzP9cCQNnXZVgnYQ_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[83].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[83].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, instTypeBoundOp);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[83].typ = (&NTI__9amcenQyXzP9cCQNnXZVgnYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[83].name = "instTypeBoundOp";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[45] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[84];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[84].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[84].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, selfName);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[84].typ = (&NTI__B0xRsLi0eK4raPu9bd2tkcA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[84].name = "selfName";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[46] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[85];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[85].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[85].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, cache);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[85].typ = (&NTI__lnkYNZP9asc88UfiEGjLrbA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[85].name = "cache";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[47] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[86];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[86].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[86].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, graph);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[86].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[86].name = "graph";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[48] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[87];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[87].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[87].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, signatures);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[87].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[87].name = "signatures";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[49] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[88];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[88].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[88].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, recursiveDep);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[88].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[88].name = "recursiveDep";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[50] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[89];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[89].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[89].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, suggestionsMade);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[89].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[89].name = "suggestionsMade";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[51] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[90];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[90].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[90].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, features);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[90].typ = (&NTI__EzHX7W9bI4X0gV7sP2f0N9cQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[90].name = "features";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[52] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[91];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[91].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[91].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, inTypeContext);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[91].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[91].name = "inTypeContext";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[53] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[92];
NTI__KlSLWBROOViO04uLQHu7ig_.size = sizeof(tyTuple__KlSLWBROOViO04uLQHu7ig);
NTI__KlSLWBROOViO04uLQHu7ig_.align = NIM_ALIGNOF(tyTuple__KlSLWBROOViO04uLQHu7ig);
NTI__KlSLWBROOViO04uLQHu7ig_.kind = 18;
NTI__KlSLWBROOViO04uLQHu7ig_.base = 0;
NTI__KlSLWBROOViO04uLQHu7ig_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_11_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[94];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[94].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[94].offset = offsetof(tyTuple__KlSLWBROOViO04uLQHu7ig, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[94].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[94].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_11_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[95];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[95].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[95].offset = offsetof(tyTuple__KlSLWBROOViO04uLQHu7ig, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[95].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[95].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[93].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[93].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[93].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_11_2[0];
NTI__KlSLWBROOViO04uLQHu7ig_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[93];
NTI__YceFcaugL2PWNtVbyffD9bQ_.size = sizeof(tySequence__YceFcaugL2PWNtVbyffD9bQ*);
NTI__YceFcaugL2PWNtVbyffD9bQ_.align = NIM_ALIGNOF(tySequence__YceFcaugL2PWNtVbyffD9bQ*);
NTI__YceFcaugL2PWNtVbyffD9bQ_.kind = 24;
NTI__YceFcaugL2PWNtVbyffD9bQ_.base = (&NTI__KlSLWBROOViO04uLQHu7ig_);
NTI__YceFcaugL2PWNtVbyffD9bQ_.flags = 2;
NTI__YceFcaugL2PWNtVbyffD9bQ_.marker = Marker_tySequence__YceFcaugL2PWNtVbyffD9bQ;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[92].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[92].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, typesWithOps);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[92].typ = (&NTI__YceFcaugL2PWNtVbyffD9bQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[92].name = "typesWithOps";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[54] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[96];
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.size = sizeof(tyTuple__DJxbl4DYEJfb29cy1MYaUPQ);
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.align = NIM_ALIGNOF(tyTuple__DJxbl4DYEJfb29cy1MYaUPQ);
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.kind = 18;
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.base = 0;
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.flags = 2;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_12_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[98];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[98].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[98].offset = offsetof(tyTuple__DJxbl4DYEJfb29cy1MYaUPQ, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[98].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[98].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_12_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[99];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[99].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[99].offset = offsetof(tyTuple__DJxbl4DYEJfb29cy1MYaUPQ, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[99].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[99].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[97].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[97].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[97].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_12_2[0];
NTI__DJxbl4DYEJfb29cy1MYaUPQ_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[97];
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.size = sizeof(tySequence__d4l6E4jBnTQ3BEfsLOpmEQ*);
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.align = NIM_ALIGNOF(tySequence__d4l6E4jBnTQ3BEfsLOpmEQ*);
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.kind = 24;
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.base = (&NTI__DJxbl4DYEJfb29cy1MYaUPQ_);
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.flags = 2;
NTI__d4l6E4jBnTQ3BEfsLOpmEQ_.marker = Marker_tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[96].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[96].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, unusedImports);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[96].typ = (&NTI__d4l6E4jBnTQ3BEfsLOpmEQ_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[96].name = "unusedImports";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[55] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[100];
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.size = sizeof(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ);
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.align = NIM_ALIGNOF(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ);
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.kind = 18;
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.base = 0;
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.flags = 3;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_13_2[0] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[102];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[102].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[102].offset = offsetof(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, Field0);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[102].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[102].name = "Field0";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_13_2[1] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[103];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[103].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[103].offset = offsetof(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, Field1);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[103].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[103].name = "Field1";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[101].len = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[101].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[101].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_13_2[0];
NTI__1v9bKyksXWMsm0vNwmZ4EuQ_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[101];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[100].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[100].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, exportIndirections);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[100].typ = (&NTI__Gy4haGrophX9bC5RxnPAc6w_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[100].name = "exportIndirections";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[56] = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[104];
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[104].kind = 1;
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[104].offset = offsetof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug, lastTLineInfo);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[104].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[104].name = "lastTLineInfo";
TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[0].len = 57; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[0].kind = 2; TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[0].sons = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_2_57[0];
NTI__C9bB2okDBl3OKGUBiY5k5Ug_.node = &TM__oylmf9cXfpJWZ2cwj9b09bJaw_0[0];
NTI__EjEifkTC8tg9afiUW4StSSA_.size = sizeof(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*);
NTI__EjEifkTC8tg9afiUW4StSSA_.align = NIM_ALIGNOF(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*);
NTI__EjEifkTC8tg9afiUW4StSSA_.kind = 22;
NTI__EjEifkTC8tg9afiUW4StSSA_.base = (&NTI__C9bB2okDBl3OKGUBiY5k5Ug_);
NTI__EjEifkTC8tg9afiUW4StSSA_.marker = Marker_tyRef__EjEifkTC8tg9afiUW4StSSA;
}

